Reference
=========

.. toctree::
   :maxdepth: 1
   :hidden:

   aws_reference
   gcp_reference
   azure_reference

.. panels::
   :card: border-0
   :container: container-lg pb-3
   :column: col-md-6 col-md-6 p-2
   :body: text-center border-0
   :header: text-center border-0 h4 bg-white
   :footer: border-0 bg-white

   AWS Reference
   ^^^^^^^^^^^^^

   .. figure:: images/logo-aws.png
      :width: 35%
      :alt: AWS logo

   +++

   .. link-button:: aws_reference
      :type: ref
      :text: AWS Reference
      :classes: btn-full btn-block stretched-link

   ---


   GCP Reference
   ^^^^^^^^^^^^^

   .. figure:: images/logo-gcp.png
      :width: 100%
      :alt: Google Cloud logo

   +++

   .. link-button:: gcp_reference
      :type: ref
      :text: Google Cloud Reference
      :classes: btn-full btn-block stretched-link



   